Function to download raw or parsed results for the countries,
companies and facilities available from the AGSI/ALSI+ API of GIE. The EIC codes
of the results can be used to in turn download the actual data
using get_giedata().
Usage
get_gielisting(
region = NULL,
country = NULL,
facilities = FALSE,
database = "agsi",
apikey = Sys.getenv("GIE_APIKEY")
)
Value
Data.frame with results
Arguments
region
Character. The broader region you want results for (can be 'Europe' or 'Non-EU').
country
Character. The country you want the results for (must be the
written-out name (e.g., "Germany"), NOT the two-digit country code).
If you use this parameter, you have to specify the 'region' parameter accordingly.
facilities
Logical. If TRUE, facility data will be added to the country or company results.
If you use this parameter, 'region' and 'country' have to be set. Defaults to FALSE.
database
Character. The type of API you want to address ('agsi' or 'alsi').
As of yet, only 'agsi' works, 'alsi' support is expected at a later time.